# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['qualtrics_utils', 'qualtrics_utils.codebook']

package_data = \
{'': ['*']}

install_requires = \
['googleapiutils2>=0.5.8,<0.6.0',
 'numpy>=1.24.3,<2.0.0',
 'pandas>=2.0.1,<3.0.0',
 'requests>=2.30.0,<3.0.0']

setup_kwargs = {
    'name': 'qualtrics-utils',
    'version': '0.5.3',
    'description': 'Utilities for qualtrics surveys.',
    'long_description': '# qualtrics-utils\n\nUtilities for qualtrics surveys. Get survey responses, generate codebooks, & c.\n\n## [`surveys`](qualtrics_utils/surveys.py)\n\nModule to interact with Qualtrics surveys.\n\nExample (get a survey\'s responses, convert to a pandas DataFrame):\n\n```python\nfrom qualtrics_utils.survey import Surveys\n\nqs = Surveys(api_token=QUALTRICS_API_TOKEN)\n\nexported_file = qs.get_responses_df(\n    surveyId=SURVEY_ID, parse_dates=["StartDate", "EndDate"]\n)\ndf = exported_file.data\n```\n\n## Codebook mapping\n\n### [`generate.py`](qualtrics_utils/codebook/generate_codebook.py)\n\nTakes the exported `.qsf` file from Qualtrics and generates a codebook mapping question\nIDs to question text and answer choices. The output is a JSON file containing a list of\ndictionaries.\n\nExample row:\n\n```json\n{\n        "question_number": "Q5.10",\n        "question_string": "What is your role at this school?"\n        "answer_choices": ...\n},\n```\n\n### [`map_columns.py`](qualtrics_utils/codebook/map_codebook_columns.py)\n\nTakes a codebook mapping (generated by the above function) and creates conditional\nstatements to map the question columns into valid Tableau or SQL code. Used to create a\nsingular question column in the above formats when there are multiple questions in a\nsingle question block (e.g. multiple Likert scale questions).\n',
    'author': 'Mike Babb',
    'author_email': 'mike7400@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/mkbabb/qualtrics-utils',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
